@@ -12,11 +12,11 @@ Map::Tube::Node - Defines the node for Map::Tube
 
 =head1 VERSION
 
-Version 0.09
+Version 1.0
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '1.0';
 
 Readonly my $BAKERLOO => {
     'Harrow & Wealdstone' => 'B1',
@@ -32,18 +32,9 @@ Readonly my $BAKERLOO => {
     'Kilburn Park'        => 'B11',
     'Maida Vale'          => 'B12',
     'Warwick Avenue'      => 'B13',
-    'Paddington'          => 'PDG', # Special case
-    'Edgware Road'        => 'EDG',
     'Marleybone'          => 'B16',
-    'Baker Street'        => 'BST', # Special case
     q{Regent's Park}      => 'B18',
-    'Oxford Circus'       => 'OXC', # Special case
-    'Piccadilly Circus'   => 'PCS', # Special case
-    'Charing Cross'       => 'CRS', # Special case
-    'Embankment'          => 'EBK', # Special case
-    'Waterloo'            => 'WLO', # Special case
     'Lambeth North'       => 'B24',
-    'Elephant & Castle'   => 'EAC'  # Special case
 };
 
 Readonly my $CENTRAL => {
@@ -54,31 +45,18 @@ Readonly my $CENTRAL => {
     'Greenford'              => 'C5',
     'Perivale'               => 'C6',
     'Hanger Lane'            => 'C7',
-    'North Acton'            => 'NAC', # Special case
-    'Ealing Broadway'        => 'EBW', # Special case
     'West Acton'             => 'C10',
     'East Acton'             => 'C11',
-    'White City'             => 'WTC', # Special case
     q{Shepherd's Bush}       => 'C13',
     'Holland Park'           => 'C14',
-    'Notting Hill Gate'      => 'NHG', # Special case
     'Queensway'              => 'C16',
     'Lancaster Gate'         => 'C17',
     'Marble Arch'            => 'C18',
-    'Bond Street'            => 'BOS', # Special case
-    'Oxford Circus'          => 'OXC', # Special case
-    'Tottenham Court Road'   => 'TCR', # Special case
-    'Holborn'                => 'HBN',
     'Chancery Lane'          => 'C23',
     q{St. Paul's}            => 'C24',
-    'Bank'                   => 'BNK', # Special case
-    'Moorgate'               => 'MGT', # Special case
-    'Liverpool Street'       => 'LST', # Special case
     'Bethnal Green'          => 'C29',
-    'Mile End'               => 'MEN', # Special case
     'Stratford'              => 'C31',
     'Leyton'                 => 'C32',
-    'Leytonstone'            => 'LES', # Special case
     'Wanstead'               => 'C34',
     'Redbridge'              => 'C35',
     'Gants Hill'             => 'C36',
@@ -92,82 +70,13 @@ Readonly my $CENTRAL => {
     'Snaresbrook'            => 'C44',
     'South Woodford'         => 'C45',
     'Woodford'               => 'C46',
-    'Buckhurst Hill'         => 'BHH', # Special case
     'Loughton'               => 'C48',
     'Debden'                 => 'C49',
     'Theydon Bois'           => 'C50',
     'Epping'                 => 'C51'
 };
 
-Readonly my $CIRCLE => {
-    'Edgware Road'              => 'EDG', # Special case
-    'Bayswater'                 => 'BYW', # Special case
-    'Notting Hill Gate'         => 'NHG', # Special case
-    'High Street Kensington'    => 'HSK', # Special case
-    'Gloucester Road',          => 'GLS', # Special case
-    'South Kensington'          => 'SKN', # Special case
-    'Sloane Square'             => 'SLQ', # Special case
-    'Victoria'                  => 'VCT', # Special case
-    q{St. James's Park}         => 'SJP', # Special case
-    'Westminster'               => 'WMN', # Special case
-    'Embankment'                => 'EBK', # Special case
-    'Temple'                    => 'TMP', # Special case
-    'Blackfriars'               => 'BLF', # Special case
-    'Mansion House'             => 'MSH', # Special case
-    'Cannon Street'             => 'CNS', # Special case
-    'Monument'                  => 'MMT', # Special case
-    'Tower Hill'                => 'THL', # Special case
-    'Aldgate'                   => 'AGT', # Special case
-    'Liverpool Street'          => 'LST', # Speical case
-    'Moorgate'                  => 'MGT', # Special case
-    'Barbican'                  => 'BBC', # Special case
-    'Farringdon'                => 'FRG', # Special case
-    q{King's Cross St. Pancras} => 'KCS', # Special case
-    'Euston Square'             => 'ESQ', # Special case
-    'Great Portland Street'     => 'GPS', # Special case
-    'Baker Street'              => 'BST', # Special case
-    'Edgware Road'              => 'EDG', # Special case
-    'Paddington'                => 'PDG', # Special case
-    'Royal Oak'                 => 'RYL', # Special case
-    'Westbourne Park'           => 'WBP', # Special case
-    'Ladbroke Grove'            => 'LBG', # Special case
-    'Latimer Road'              => 'LTR', # Special case
-    'White City'                => 'WTC', # Special case
-    'Wood Lane'                 => 'WDL', # Special case
-    q{Shepherd's Bush Market}   => 'SBM', # Special case
-    'Goldhawk Road'             => 'GHR', # Special case
-    'Hammersmith'               => 'HSM'  # Special case
-};
-
 Readonly my $DISTRICT => {
-    'Edgware Road'              => 'EDG', # Special case
-    'Bayswater'                 => 'BYW', # Special case
-    'Notting Hill Gate'         => 'NHG', # Special case
-    'High Street Kensington'    => 'HSK', # Special case
-    'Gloucester Road',          => 'GLS', # Special case
-    'South Kensington'          => 'SKN', # Special case
-    'Sloane Square'             => 'SLQ', # Special case
-    'Victoria'                  => 'VCT', # Special case
-    q{St. James's Park}         => 'SJP', # Special case
-    'Westminster'               => 'WMN', # Special case
-    'Embankment'                => 'EBK', # Special case
-    'Temple'                    => 'TMP', # Special case
-    'Blackfriars'               => 'BLF', # Special case
-    'Mansion House'             => 'MSH', # Special case
-    'Cannon Street'             => 'CNS', # Special case
-    'Monument'                  => 'MMT', # Special case
-    'Tower Hill'                => 'THL', # Special case
-    'Aldgate East'              => 'AGE', # Special case
-    'Whitechapel'               => 'WCH', # Special case
-    'Stepney Green'             => 'SGN', # Special case
-    'Mile End'                  => 'MEN', # Special case
-    'Bow Road'                  => 'BRD', # Special case
-    'Bromley-by-Bow'            => 'BBB', # Special case
-    'West Ham'                  => 'WHM', # Special case
-    'Plaistow'                  => 'PST', # Special case
-    'Upton Park'                => 'UPK', # Special case
-    'East Ham'                  => 'EHM', # Special case
-    'Barking'                   => 'BKG', # Special case
     'Upney'                     => 'D29',
     'Becontree'                 => 'D30',
     'Dagenham Heathway'         => 'D31',
@@ -176,21 +85,10 @@ Readonly my $DISTRICT => {
     'Hornchurch'                => 'D34',
     'Upminster Bridge'          => 'D35',
     'Upminster'                 => 'D36',
-    q{Earl's Court}             => 'ECT', # Special case
     'West Kensington'           => 'D38',
-    'Barons Court'              => 'BCT', # Special case
-    'Hammersmith'               => 'HSM', # Special case
     'Ravenscourt Park'          => 'D41',
     'Stamford Brook'            => 'D42',
-    'Turnham Green'             => 'TGN', # Special case
     'Chiswick Park'             => 'D44',
-    'Acton Town'                => 'ACT', # Special case
-    'Ealing Common'             => 'ECM', # Special case
-    'Ealing Broadway'           => 'EBW', # Special case
-    'Gunnersbury'               => 'GBY', # Special case
-    'Kew Gardens'               => 'KGN', # Special case
-    'Richmond'                  => 'RCH', # Special case
-    'West Brompton'             => 'WBM', # Special case
     'Fulham Broadway'           => 'D52',
     'Parsons Green'             => 'D53',
     'Putney Bridge'             => 'D54',
@@ -198,104 +96,41 @@ Readonly my $DISTRICT => {
     'Southfields'               => 'D56',
     'Wimbledon Park'            => 'D57',
     'Wimbledon'                 => 'D58',
-    'Kensington (Olympia)'      => 'KSG' # Special case
-};
-
-Readonly my $HAMMERSMITHANDCITY => {
-    'Barking'                   => 'BKG', # Special case
-    'East Ham'                  => 'EHM', # Special case
-    'Plaistow'                  => 'PST', # Special case
-    'West Ham'                  => 'WHM', # Special case
-    'Bromley-by-Bow'            => 'BBB', # Special case
-    'Bow Road'                  => 'BRD', # Special case
-    'Mile End'                  => 'MEN', # Special case
-    'Stepney Green'             => 'SGN', # Special case
-    'Whitechapel'               => 'WCH', # Special case
-    'Aldgate East'              => 'AGE', # Special case
-    'Liverpool Street'          => 'LST', # Speical case
-    'Moorgate'                  => 'MGT', # Special case
-    'Barbican'                  => 'BBC', # Special case
-    'Farringdon'                => 'FRG', # Special case
-    q{King's Cross St. Pancras} => 'KCS', # Special case
-    'Euston Square'             => 'ESQ', # Special case
-    'Great Portland Street'     => 'GPS', # Special case
-    'Baker Street'              => 'BST', # Special case
-    'Edgware Road'              => 'EDG', # Special case
-    'Paddington'                => 'PDG', # Special case
-    'Royal Oak'                 => 'RYL', # Special case
-    'Westbourne Park'           => 'WBP', # Special case
-    'Ladbroke Grove'            => 'LBG', # Special case
-    'Latimer Road'              => 'LTR', # Special case
-    'White City'                => 'WTC', # Special case
-    'Wood Lane'                 => 'WDL', # Special case
-    q{Shepherd's Bush Market}   => 'SBM', # Special case
-    'Goldhawk Road'             => 'GHR', # Special case
-    'Hammersmith'               => 'HSM'  # Special case
 };
 
 Readonly my $JUBILEE => {
-    'Stanmore'         => 'J1',
-    'Canons Park'      => 'J2',
-    'Queensbury'       => 'J3',
-    'Kingsbury'        => 'J4',
-    'Wembley Park'     => 'WMB', # Special case
     'Neasden'          => 'J6',
     'Dollis Hill'      => 'J7',
     'Willesden Green'  => 'J8',
     'Kilburn'          => 'J9',
     'West Hampstead'   => 'J10',
-    'Finchley Road'    => 'FNR', # Special case
+    'Stanmore'         => 'J1',
+    'Canons Park'      => 'J2',
+    'Queensbury'       => 'J3',
+    'Kingsbury'        => 'J4',
     'Swiss Cottage'    => 'J12',
     q{St. John's Wood} => 'J13',
-    'Baker Street'     => 'BST', # Special case
-    'Bond Street'      => 'BOS', # Special case
-    'Green Park'       => 'GPK', # Special case
-    'Westminster'      => 'WMN', # Special case
-    'Waterloo'         => 'WLO', # Special case
     'Southwark'        => 'J19',
-    'London Bridge'    => 'LON', # Special case
     'Bermondsey'       => 'J21',
     'Canada Water'     => 'J22',
     'Canary Wharf'     => 'J23',
     'North Greenwich'  => 'J24',
     'Canning Town'     => 'J25',
-    'West Ham'         => 'WHM', # Special case
     'Stratford'        => 'J27'
 };
 
 Readonly my $METROPOLITAN => {
-    'Aldgate'                   => 'AGT', # Special case
-    'Liverpool Street'          => 'LST', # Speical case
-    'Moorgate'                  => 'MGT', # Special case
-    'Barbican'                  => 'BBC', # Special case
-    'Farringdon'                => 'FRG', # Special case
-    q{King's Cross St. Pancras} => 'KCS', # Special case
-    'Euston Square'             => 'ESQ', # Special case
-    'Great Portland Street'     => 'GPS', # Special case
-    'Baker Street'              => 'BST', # Special case
-    'Finchley Road'             => 'FNR', # Special case
-    'Wembley Park'              => 'WMB', # Special case
     'Preston Road'              => 'M12',
     'Norhtwick Park'            => 'M13',
-    'Harrow-on-the-Hill'        => 'HOH', # Special case
     'West Harrow'               => 'M15',
-    'Rayners Lane'              => 'RAL', # Special case
-    'Eastcote'                  => 'ETC',
-    'Ruislip Manor'             => 'RSM',
-    'Ruislip'                   => 'RSP',
-    'Ickenham'                  => 'IKH',
-    'Hillingdon'                => 'HGD',
-    'Uxbridge'                  => 'UXB',
     'North Harrow'              => 'M23',
     'Pinner'                    => 'M24',
     'Northwood Hills'           => 'M25',
     'Northwood'                 => 'M26',
-    'Moor Park'                 => 'MPK', # Special case
     'Croxley'                   => 'M28',
     'Watford'                   => 'M29',
     'Rickmansworth'             => 'M30',
     'Chorleywood'               => 'M31',
-    'Chalfont & Latimer'        => 'CAL', # Special case
     'Chesham'                   => 'M33',
     'Amersham'                  => 'M34'
 };
@@ -309,7 +144,6 @@ Readonly my $NORTHERN => {
     'Hampstead'              => 'N6',
     'Belsize Park'           => 'N7',
     'Chalk Farm'             => 'N8',
-    'Camden Town'            => 'CAT',
     'Kentish Town'           => 'N10',
     'Tufnell Park'           => 'N11',
     'Archway'                => 'N12',
@@ -322,17 +156,8 @@ Readonly my $NORTHERN => {
     'Totteridge & Whetstone' => 'N19',
     'High Barnet'            => 'N20',
     'Momington Crescent'     => 'N21',
-    'Euston'                 => 'EUS',
-    'Warren Street'          => 'WST',
     'Goodge Street'          => 'N24',
-    'Tottenham Court Road'   => 'TCR',
-    'Leicester Square'       => 'LSQ',
-    'Charing Cross'          => 'CRS',
-    'Embankment'             => 'EBK',
-    'Waterloo'               => 'WLO',
-    'Kennington'             => 'KNG',
     'Oval'                   => 'N31',
-    'Stockwell'              => 'STW',
     'Clapham North'          => 'N33',
     'Clapham Common'         => 'N34',
     'Clapham South'          => 'N35',
@@ -342,124 +167,186 @@ Readonly my $NORTHERN => {
     'Collers Wood'           => 'N39',
     'South Wimbledon'        => 'N40',
     'Morden'                 => 'N41',
-    'Elephant & Castle'      => 'EAC',
     'Borough'                => 'N42',
-    'London Bridge'          => 'LON',
-    'Bank'                   => 'BNK',
-    'Moorgate'               => 'MGT',
     'Old Street'             => 'N46',
     'Angel'                  => 'N47',
-    q{King's Cross St. Pancras} => 'KCS'
 };
 
 Readonly my $PICCADILLY => {
-    'Uxbridge'                  => 'UXB', # Special case
-    'Hillingdon'                => 'HGD', # Special case
-    'Ruislip Manor'             => 'RSM', # Special case
-    'Ickenham'                  => 'IKH', # Special case
-    'Ruislip'                   => 'RSP', # Special case
-    'Eastcote'                  => 'ETC', # Special case
-    'Rayners Lane'              => 'RAL', # Special case
-	'South Harrow'              => 'P8',
-	'Sudbury Hill'              => 'P9',
-	'Sudbury Town'              => 'P10',
-	'Alperton'                  => 'P11',
-	'Park Royal'                => 'P12',
-	'North Ealing'              => 'P13',
-    'Ealing Common'             => 'ECM', # Special case
-    'Acton Town'                => 'ACT', # Special case
-    'Turnham Green'             => 'TGN', # Special case
-    'Hammersmith'               => 'HSM', # Special case
-    'Barons Court'              => 'BCT', # Special case
-    q{Earl's Court}             => 'ECT', # Special case
-    'Gloucester Road',          => 'GLS', # Special case
-    'South Kensington'          => 'SKN', # Special case
-	'Knightsbridge'             => 'P22',
-	'Hyde Park Corner'          => 'P23',
-	'Green Park'                => 'GPK', # Special case
-	'Piccadilly Circus'         => 'PCS', # Special case
-	'Leicester Square'          => 'LSQ',
-	'Covent Garden'             => 'P27',
-	'Holborn'                   => 'HBN',
-	'Russel Square'             => 'P29',
-	q{King's Cross St. Pancras} => 'KCS', # Special case
-	'Caledonian Road'           => 'P31',
-	'Holloway Road'             => 'P32',
-	'Arsenal'                   => 'P33',
-	'Finsbury Park'             => 'FBP',
-	'Manor House'               => 'P35',
-	'Turnpike Lane'             => 'P36',
-	'Wood Green'                => 'P37',
-	'Bounds Green'              => 'P38',
-	'Arnos Grove'               => 'P39',
-	'Southgate'                 => 'P40',
-	'Oakwood'                   => 'P41',
-	'Cockfosters'               => 'P42',
-	'South Ealing'              => 'P43',
+    'South Harrow'              => 'P8',
+    'Sudbury Hill'              => 'P9',
+    'Sudbury Town'              => 'P10',
+    'Park Royal'                => 'P12',
+    'North Ealing'              => 'P13',
+    'Knightsbridge'             => 'P22',
+    'Hyde Park Corner'          => 'P23',
+    'Covent Garden'             => 'P27',
+    'Russel Square'             => 'P29',
+    'Caledonian Road'           => 'P31',
+    'Holloway Road'             => 'P32',
+    'Arsenal'                   => 'P33',
+    'Manor House'               => 'P35',
+    'Turnpike Lane'             => 'P36',
+    'Wood Green'                => 'P37',
+    'Bounds Green'              => 'P38',
+    'Arnos Grove'               => 'P39',
+    'Southgate'                 => 'P40',
+    'Oakwood'                   => 'P41',
+    'Cockfosters'               => 'P42',
+    'South Ealing'              => 'P43',
     'Northfields'               => 'P44',
-	'Boston Manor'              => 'P45',
-	'Osterley'                  => 'P46',
-	'Hounslow East'             => 'P47',
-	'Hounslow Central'          => 'P48',
-	'Hounslow West'             => 'P49',
-	'Hatton Cross'              => 'P50',
-	'Heathrow Terminal 4'       => 'P51',
-	'Heathrow Terminal 1,2,3'   => 'P52',
-	'Heathrow Terminal 5'       => 'P53'
+    'Boston Manor'              => 'P45',
+    'Osterley'                  => 'P46',
+    'Hounslow East'             => 'P47',
+    'Hounslow Central'          => 'P48',
+    'Hounslow West'             => 'P49',
+    'Hatton Cross'              => 'P50',
+    'Heathrow Terminal 4'       => 'P51',
+    'Heathrow Terminal 1,2,3'   => 'P52',
+    'Heathrow Terminal 5'       => 'P53'
 };
 
 Readonly my $VICTORIA => {
     'Brixton'                   => 'V1',
-    'Stockwell'                 => 'STW',
     'Vauxhall'                  => 'V3',
     'Pimlico'                   => 'V4',
-    'Victoria'                  => 'VCT', # Special case
-    'Green Park'                => 'GPK', # Special case
-    'Oxford Circus'             => 'OXC', # Special case
-    'Warren Street'             => 'WST', # Special case
     'Euston'                    => 'V9',
-    q{King's Cross St. Pancras} => 'KCS', # Special case
     'Highbury & Islington'      => 'V11',
-    'Finsbury Park'             => 'FBP',
     'Seven Sisters'             => 'V13',
     'Tottenham Hale'            => 'V14',
     'Blackhose Road'            => 'V15',
     'Walthamstow Central'       => 'V16'
 };
 
+Readonly my $COMMON => {
+    'Acton Town'                => 'ACT',
+    'Aldgate'                   => 'AGT',
+    'Aldgate East'              => 'AGE',
+    'Alperton'                  => 'P11',
+    'Baker Street'              => 'BST',
+    'Bank'                      => 'BNK',
+    'Barbican'                  => 'BBC',
+    'Barking'                   => 'BKG',
+    'Barons Court'              => 'BCT',
+    'Bayswater'                 => 'BYW',
+    'Blackfriars'               => 'BLF',
+    'Bond Street'               => 'BOS',
+    'Bow Road'                  => 'BRD',
+    'Bromley-by-Bow'            => 'BBB',
+    'Buckhurst Hill'            => 'BHH',
+    'Cannon Street'             => 'CNS',
+    'Chalfont & Latimer'        => 'CAL',
+    'Camden Town'               => 'CAT',
+    'Charing Cross'             => 'CRS',
+    'Ealing Broadway'           => 'EBW',
+    'Ealing Common'             => 'ECM',
+    q{Earl's Court}             => 'ECT',
+    'East Ham'                  => 'EHM',
+    'Eastcote'                  => 'ETC',
+    'Edgware Road'              => 'EDG',
+    'Elephant & Castle'         => 'EAC',
+    'Embankment'                => 'EBK',
+    'Euston'                    => 'EUS',
+    'Euston Square'             => 'ESQ',
+    'Farringdon'                => 'FRG',
+    'Finchley Road'             => 'FNR',
+    'Finsbury Park'             => 'FBP',
+    'Gloucester Road'           => 'GLS',
+    'Goldhawk Road'             => 'GHR',
+    'Great Portland Street'     => 'GPS',
+    'Green Park'                => 'GPK',
+    'Gunnersbury'               => 'GBY',
+    'Hammersmith'               => 'HSM',
+    'Harrow-on-the-Hill'        => 'HOH',
+    'High Street Kensington'    => 'HSK',
+    'Hillingdon'                => 'HGD',
+    'Holborn'                   => 'HBN',
+    'Ickenham'                  => 'IKH',
+    'Kennington'                => 'KNG',
+    'Kensington (Olympia)'      => 'KSG',
+    'Kew Gardens'               => 'KGN',
+    q{King's Cross St. Pancras} => 'KCS',
+    'Ladbroke Grove'            => 'LBG',
+    'Latimer Road'              => 'LTR',
+    'Leicester Square'          => 'LSQ',
+    'Leytonstone'               => 'LES',
+    'Liverpool Street'          => 'LST',
+    'London Bridge'             => 'LON',
+    'Mansion House'             => 'MSH',
+    'Mile End'                  => 'MEN',
+    'Monument'                  => 'MMT',
+    'Moor Park'                 => 'MPK',
+    'Moorgate'                  => 'MGT',
+    'North Acton'               => 'NAC',
+    'Notting Hill Gate'         => 'NHG',
+    'Oxford Circus'             => 'OXC',
+    'Paddington'                => 'PDG',
+    'Piccadilly Circus'         => 'PCS',
+    'Plaistow'                  => 'PST',
+    'Rayners Lane'              => 'RAL',
+    'Richmond'                  => 'RCH',
+    'Royal Oak'                 => 'RYL',
+    'Ruislip'                   => 'RSP',
+    'Ruislip Manor'             => 'RSM',
+    q{Shepherd's Bush Market}   => 'SBM',
+    'Sloane Square'             => 'SLQ',
+    'South Kensington'          => 'SKN',
+    q{St. James's Park}         => 'SJP',
+    'Stepney Green'             => 'SGN',
+    'Stockwell'                 => 'STW',
+    'Temple'                    => 'TMP',
+    'Tottenham Court Road'      => 'TCR',
+    'Tower Hill'                => 'THL',
+    'Turnham Green'             => 'TGN',
+    'Upton Park'                => 'UPK',
+    'Uxbridge'                  => 'UXB',
+    'Victoria'                  => 'VCT',
+    'Warren Street'             => 'WST',
+    'Waterloo'                  => 'WLO',
+    'Wembley Park'              => 'WMB',
+    'West Brompton'             => 'WBM',
+    'West Ham'                  => 'WHM',
+    'Westbourne Park'           => 'WBP',
+    'Westminster'               => 'WMN',
+    'White City'                => 'WTC',
+    'Whitechapel'               => 'WCH',
+    'Wood Lane'                 => 'WDL',
+};
+
 =head1 SYNOPSIS
 
 Here is sample map
 
-    1 --------  2
+    B --------  C 
    /  \       /  \
   /    \     /    \
  /      \   /      \
-0 ------  6 ------- 3
+A ------  G ------- D
  \      /   \      /
   \    /     \    /
-   \  /       \  /
-    5 -------- 4
+   \  /       \  / 
+    F -------- E 
    /
   /
- /
-7
+ /  
+H
  \
   \
    \
-    8
-
+    I 
+   
 which can be defined as below:
 
-{ 0 => [1,5,6],
-  1 => [0,2,6],
-  2 => [1,3,6],
-  3 => [2,4,6],
-  4 => [3,5,6],
-  5 => [0,4,6,7],
-  6 => [0,1,2,3,4,5],
-  7 => [5,8],
-  8 => [7],};
+{ 'A' => ['B','F','G'],
+  'B' => ['A','C','G'],
+  'C' => ['B','D','G'],
+  'D' => ['C','E','G'],
+  'E' => ['D','F','G'],
+  'F' => ['A','E','G','H'],
+  'G' => ['A','B','C','D','E','F'],
+  'H' => ['F','I'],
+  'I' => ['H']
+}
 
 =cut
 
@@ -467,7 +354,8 @@ which can be defined as below:
 
 =head2 init()
 
-This is the core method of the module, where we actually define the relationship among the diffrerent nodes. I have taken extra care to depict the relationship.
+This is the core method of the module, where we actually define the relationship 
+among the diffrerent nodes. I have taken extra care to depict the relationship.
 However I would be more than happy to receieve any suggestion to improve the logic.
 Please note "Transport for London" is the owner of the data used here.
 
@@ -531,29 +419,6 @@ sub init {
         'C50' => ['C49','C51'],
         'C51' => ['C50'],
 
-        ## CIRCLE / HAMMERSMITHANDCITY
-        'GHR' => ['HSM','SBM'],
-        'SBM' => ['GHR','WDL'],
-        'WDL' => ['WTC','SBM'],
-        'LTR' => ['WTC','LBG'],
-        'LBG' => ['LTR','WBP'],
-        'WBP' => ['LBG','RYL'],
-        'RYL' => ['WBP','PDG'],
-        'GPS' => ['BST','ESQ'],
-        'FRG' => ['KCS','BBC'],
-        'BBC' => ['FRG','MGT'],
-        'AGT' => ['LST','THL'],
-        'MMT' => ['THL','CNS'],
-        'CNS' => ['MMT','MSH'],
-        'MSH' => ['CNS','BLF'],
-        'BLF' => ['TMP','MSH'],
-        'TMP' => ['BLF','EBK'],
-        'EBK' => ['WMN','TMP'],
-        'SJP' => ['WMN','VCT'],
-        'SLQ' => ['VCT','SKN'],
-        'HSK' => ['GLS','NHG'],
-        'BYW' => ['NHG','EDG'],
-
         ## DISTRICT / HAMMERSMITHANDCITY
         'D36' => ['D35'],
         'D35' => ['D34','D36'],
@@ -563,22 +428,10 @@ sub init {
         'D31' => ['D30','D32'],
         'D30' => ['D29','D31'],
         'D29' => ['BKG','D30'],
-        'BKG' => ['EHM','D29'],
-        'EHM' => ['UPK','BKG'],
-        'UPK' => ['PST','EHM'],
-        'PST' => ['WHM','UPK'],
-        'BBB' => ['WHM','BRD'],
-        'BRD' => ['MEN','BBB'],
-        'SGN' => ['WCH','MEN'],
-        'WCH' => ['AGE','SGN'],
         'D38' => ['ECT','BCT'],
-        'BCT' => ['HSM','D38'],
         'D41' => ['HSM','D42'],
         'D42' => ['TGN','D41'],
         'D44' => ['TGN','ACT'],
-        'GBY' => ['TGN','KGN'],
-        'KGN' => ['GBY','RCH'],
-        'RCH' => ['KGN'],
 
         ## JUBILEE
         'J1'  => ['J2'],
@@ -603,12 +456,6 @@ sub init {
         ## METROPOLITAN
         'M12' => ['FNR','M13'],
         'M15' => ['HOH','RAL'],
-        'ETC' => ['RAL','RSM'],
-        'RSM' => ['ETC','RSP'],
-        'RSP' => ['RSM','IKH'],
-        'IKH' => ['RSP','HGD'],
-        'HGD' => ['IKH','UXB'],
-        'UXB' => ['HGD'],
         'M23' => ['HOH','M24'],
         'M24' => ['M23','M25'],
         'M25' => ['M24','M26'],
@@ -656,39 +503,39 @@ sub init {
         'N47' => ['N46','KCS'],
 
         ## PICCADILLY
-	    'P53' => ['P52'],
-	    'P52' => ['P53','P50'],
-	    'P51' => ['P52'],
-	    'P50' => ['P51'],
-	    'P49' => ['P50','P48'],
-	    'P48' => ['P49','P47'],
-	    'P47' => ['P48','P46'],
-	    'P46' => ['P47','P45'],
-	    'P45' => ['P46','P44'],
-	    'P44' => ['P45','P43'],
-	    'P43' => ['ACT','P44'],
-	    'P42' => ['P41'],
-	    'P41' => ['P40','P42'],
-	    'P40' => ['P39','P41'],
-	    'P39' => ['P38','P40'],
-	    'P38' => ['P37','P39'],
-	    'P37' => ['P36','P38'],
-	    'P36' => ['P35','P37'],
-	    'P35' => ['FBP','P36'],
-	    'P33' => ['FBP','P32'],
-	    'P32' => ['P33','P31'],
-	    'P31' => ['P32','KCS'],
-	    'P29' => ['KCS','HBN'],
-	    'P27' => ['HBN','LSQ'],
-	    'P23' => ['GPK','P22'],
-	    'P22' => ['P23','SKN'],
-		'P13' => ['ECM','P12'],
-	    'P12' => ['P13','P11'],
-	    'P11' => ['P12','P10'],
-	    'P10' => ['P11','P9'],
-	    'P9'  => ['P10','P8'],
-	    'P8'  => ['RAL','P9'],
- 		
+        'P53' => ['P52'],
+        'P52' => ['P53','P50'],
+        'P51' => ['P52'],
+        'P50' => ['P51'],
+        'P49' => ['P50','P48'],
+        'P48' => ['P49','P47'],
+        'P47' => ['P48','P46'],
+        'P46' => ['P47','P45'],
+        'P45' => ['P46','P44'],
+        'P44' => ['P45','P43'],
+        'P43' => ['ACT','P44'],
+        'P42' => ['P41'],
+        'P41' => ['P40','P42'],
+        'P40' => ['P39','P41'],
+        'P39' => ['P38','P40'],
+        'P38' => ['P37','P39'],
+        'P37' => ['P36','P38'],
+        'P36' => ['P35','P37'],
+        'P35' => ['FBP','P36'],
+        'P33' => ['FBP','P32'],
+        'P32' => ['P33','P31'],
+        'P31' => ['P32','KCS'],
+        'P29' => ['KCS','HBN'],
+        'P27' => ['HBN','LSQ'],
+        'P23' => ['GPK','P22'],
+        'P22' => ['P23','SKN'],
+        'P13' => ['ECM','P12'],
+        'P12' => ['P13','P11'],
+        'P11' => ['P12','P10'],
+        'P10' => ['P11','P9'],
+        'P9'  => ['P10','P8'],
+        'P8'  => ['RAL','P9'],
+         
         ## VICTORIA
         'V1'  => ['STW'],
         'V3'  => ['STW','V4'],
@@ -702,57 +549,96 @@ sub init {
         'V17' => ['V16'],
 
         ## Special case
-        'BST' => ['BOS','B18','B16','GPS','J13','EDG','FNR'],
-        'GPK' => ['VCT','OXC','BOS','WMN','LSQ'],
-        'BOS' => ['GPK','BST','OXC','C18'],
-        'OXC' => ['V6','WST','BOS','B18','PCS','TCR'],
-        'NAC' => ['C7','C10','C11'],
-        'LES' => ['C32','C34','C44'],
+        'UXB' => ['HGD'],
+        'RCH' => ['KGN'],
+        'GHR' => ['HSM','SBM'],
+        'SBM' => ['GHR','WDL'],
+        'WDL' => ['WTC','SBM'],
+        'LTR' => ['WTC','LBG'],
+        'LBG' => ['LTR','WBP'],
+        'WBP' => ['LBG','RYL'],
+        'RYL' => ['WBP','PDG'],
+        'GPS' => ['BST','ESQ'],
+        'FRG' => ['KCS','BBC'],
+        'BBC' => ['FRG','MGT'],
+        'AGT' => ['LST','THL'],
+        'MMT' => ['THL','CNS'],
+        'CNS' => ['MMT','MSH'],
+        'MSH' => ['CNS','BLF'],
+        'BLF' => ['TMP','MSH'],
+        'TMP' => ['BLF','EBK'],
+        'EBK' => ['WMN','TMP'],
+        'SJP' => ['WMN','VCT'],
+        'SLQ' => ['VCT','SKN'],
+        'HSK' => ['GLS','NHG'],
+        'BYW' => ['NHG','EDG'],
+        'BCT' => ['HSM','D38'],
+        'GBY' => ['TGN','KGN'],
+        'KGN' => ['GBY','RCH'],
+        'BKG' => ['EHM','D29'],
+        'EHM' => ['UPK','BKG'],
+        'UPK' => ['PST','EHM'],
+        'PST' => ['WHM','UPK'],
+        'BBB' => ['WHM','BRD'],
+        'BRD' => ['MEN','BBB'],
+        'SGN' => ['WCH','MEN'],
+        'WCH' => ['AGE','SGN'],
+        'ETC' => ['RAL','RSM'],
+        'RSM' => ['ETC','RSP'],
+        'RSP' => ['RSM','IKH'],
+        'IKH' => ['RSP','HGD'],
+        'HGD' => ['IKH','UXB'],
         'BHH' => ['C43','C46'],
-        'NHG' => ['C14','C16','R2','R4'],
-        'VCT' => ['V4','GPK','R7','SJP'],
-        'WMN' => ['SJP','GPK','WLO','EBK','WLO'],
-        'PDG' => ['B13','EDG','RYL'],
-        'WTC' => ['C11','C13','LTR','WDL','C13'],
-        'EDG' => ['PDG','B16','BST'],
-        'KCS' => ['V9','V11','EUS','FRG','N47','P29','P31'],
-        'MEN' => ['C29','C31','SGN','BRD'],
-        'WHM' => ['J25','J27','BBB','PST'],
-        'HSM' => ['GHR','BCT','D41','TGN'],
         'EBW' => ['ECM','C10'],
         'AGE' => ['LST','THL'],
-        'LST' => ['MGT','AGT','AGE','BNK','C29'],
+        'STW' => ['V1','V3','N31'],
+        'NAC' => ['C7','C10','C11'],
+        'RAL' => ['M15','ETC','P8'],
         'THL' => ['AGT','AGE','MMT'],
         'GLS' => ['SKN','HSK','ECT'],
-        'ECT' => ['KSG','HSK','WBM','GLS'],
-        'TGN' => ['D42','D44','GBY','HSM','ACT'],
-        'ACT' => ['D44','ECM','P43','TGN'],
-        'WMB' => ['J4','J6','FNR','M12','HOH'],
-        'FNR' => ['J10','J12','BST','WMB'],
-        'HOH' => ['M13','WMB','M15','UXB'],
-        'RAL' => ['M15','ETC','P8'],
         'MPK' => ['M26','M28','M30'],
         'CAL' => ['M31','M33','M34'],
         'CRS' => ['PCS','EBK','LSQ'],
+        'EAC' => ['B24','KNG','N42'],
+        'FCC' => ['N14','N16','N17'],
+        'EUS' => ['WST','N21','KCS'],
+        'LSQ' => ['TCR','CRS','PCS'],
+        'KNG' => ['WLO','EAC','N31'],
+        'SKN' => ['SLQ','GLS','P22'],
+        'ECM' => ['ACT','P13','EBW'],
+        'PDG' => ['B13','EDG','RYL'],
+        'EDG' => ['PDG','B16','BST'],
+        'LES' => ['C32','C34','C44'],
+        'NHG' => ['C14','C16','R2','R4'],
+        'VCT' => ['V4','GPK','R7','SJP'],
+        'CAT' => ['N8','N10','N21','EUS'],
+        'WST' => ['OXC','V9','EUS','N24'],
+        'BOS' => ['GPK','BST','OXC','C18'],
+        'MEN' => ['C29','C31','SGN','BRD'],
+        'WHM' => ['J25','J27','BBB','PST'],
+        'HSM' => ['GHR','BCT','D41','TGN'],
+        'ACT' => ['D44','ECM','P43','TGN'],
+        'ECT' => ['KSG','HSK','WBM','GLS'],
+        'FNR' => ['J10','J12','BST','WMB'],
+        'HOH' => ['M13','WMB','M15','UXB'],
         'EBK' => ['CRS','WLO','TMP','WMN'],
         'WLO' => ['EBK','B24','WMN','J19'],
         'TCR' => ['OXC','HBN','N24','LSQ'],
-        'EAC' => ['B24','KNG','N42'],
-        'STW' => ['V1','V3','N31'],
         'LON' => ['J19','J21','N42','BNK'],
         'BNK' => ['C24','LON','MGT','LST'],
         'MGT' => ['LST','BBC','BNK','N46'],
-        'CAT' => ['N8','N10','N21','EUS'],
-        'FCC' => ['N14','N16','N17'],
-        'EUS' => ['WST','N21','KCS'],
-        'WST' => ['OXC','V9','EUS','N24'],
-        'LSQ' => ['TCR','CRS','PCS'],
-        'KNG' => ['WLO','EAC','N31'],
-		'HBN' => ['TCR','C23','P27','P29'],
-		'FBP' => ['V11','V13','P33','P35'],
-		'PCS' => ['OXC','CRS','LSQ','GPK'],
-		'SKN' => ['SLQ','GLS','P22'],
-		'ECM' => ['ACT','P13','EBW'],
+        'HBN' => ['TCR','C23','P27','P29'],
+        'FBP' => ['V11','V13','P33','P35'],
+        'PCS' => ['OXC','CRS','LSQ','GPK'],
+        'WMB' => ['J4','J6','FNR','M12','HOH'],
+        'GPK' => ['VCT','OXC','BOS','WMN','LSQ'],
+        'WMN' => ['SJP','GPK','WLO','EBK','WLO'],
+        'WTC' => ['C11','C13','LTR','WDL','C13'],
+        'LST' => ['MGT','AGT','AGE','BNK','C29'],
+        'TGN' => ['D42','D44','GBY','HSM','ACT'],
+        'OXC' => ['V6','WST','BOS','B18','PCS','TCR'],
+        'KCS' => ['V9','V11','EUS','FRG','N47','P29','P31'],
+        'BST' => ['BOS','B18','B16','GPS','J13','EDG','FNR'],
     };
     return $node;
 }
@@ -760,26 +646,46 @@ sub init {
 =head2 load_element()
 
 This loads all the nodes defined. Currently covers Bakerloo, Central, Circle,
-District, Hammersmith & City, Jubilee, Metropolitan, Northern, Piccadilly and Victoria. 
-I shall be finishing the last remaining Waterloo & City line very soon. Please note this 
-is still a very experimental in nature.
+District, Hammersmith & City, Jubilee, Metropolitan, Northern, Piccadilly and 
+Victoria. I shall be finishing the last remaining Waterloo & City line very soon. 
+Please note this is still very experimental in nature.
 
 =cut
 
 sub load_element
 {
-    return {%{$BAKERLOO},
+    return {%{$COMMON},
+            %{$BAKERLOO},
             %{$CENTRAL},
-            %{$CIRCLE},
             %{$DISTRICT},
-            %{$HAMMERSMITHANDCITY},
             %{$JUBILEE},
             %{$METROPOLITAN},
             %{$NORTHERN},
-			%{$PICCADILLY},
+            %{$PICCADILLY},
             %{$VICTORIA}};
 }
 
+=head2 upcase_element_name
+
+This loads all the nodes with name in uppercase. This is to allow case-insensitive 
+name lookup. User can also provide the node list otherwise it will pick the default list.
+
+=cut
+
+sub upcase_element_name
+{
+    my $element = shift;
+    $element = load_element() 
+        unless defined $element;
+    
+    my $upcase = undef;
+    foreach (keys %{$element})
+    {
+        $upcase->{uc($_)} = $element->{$_};
+    }
+    return $upcase;
+}
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar@yahoo.com> >>
